/*

  Nullsoft WASABI Source File License

  Copyright 1999-2001 Nullsoft, Inc.

    This software is provided 'as-is', without any express or implied
    warranty.  In no event will the authors be held liable for any damages
    arising from the use of this software.

    Permission is granted to anyone to use this software for any purpose,
    including commercial applications, and to alter it and redistribute it
    freely, subject to the following restrictions:

    1. The origin of this software must not be misrepresented; you must not
       claim that you wrote the original software. If you use this software
       in a product, an acknowledgment in the product documentation would be
       appreciated but is not required.
    2. Altered source versions must be plainly marked as such, and must not be
       misrepresented as being the original software.
    3. This notice may not be removed or altered from any source distribution.


  Brennan Underwood
  brennan@nullsoft.com

*/

/* copyright (C) 2002 HOSHINO Yoshifumi (Yoshi) */

#include "c:/Wasabi SDK/studio/bfc/std.h"

#include "gclient.h"
#include "gclientwnd.h"
#include "resource.h"

#include "c:/Wasabi SDK/studio/bfc/canvas.h"
#include "c:/Wasabi SDK/studio/common/xlatstr.h"

#define TIMER_ID       0x00FF00FF
#define TIMER_INTERVAL 200 //ms 


//  Methods required by Window Creation Services
const char *GenericWnd::getWindowTypeName() { return "gclient Window"; }
GUID GenericWnd::getWindowTypeGuid() { return the->getGUID(); }
void GenericWnd::setIconBitmaps(ButtonWnd *button) {
  button->setBitmaps(the->gethInstance(), IDB_TAB_NORMAL, NULL, IDB_TAB_HILITED, IDB_TAB_SELECTED);
}

GenericWnd::GenericWnd()
{
  pCmdProv = new CommandProvider;
  setName("Gandharva Command Client");

  m_szTitle[0] = NULL;
  m_szArtist[0] = NULL;
}

GenericWnd::~GenericWnd()
{
  if(pCmdProv) {
    pCmdProv->Close();
    delete pCmdProv;
  }

  api->core_delCallback(0, this);
}

int GenericWnd::onInit() {
  int retval = GENERICWND_PARENT::onInit();

  // Do your startup stuff here.
  api->core_addCallback(0, this);

  setTimer(TIMER_ID , TIMER_INTERVAL);
  pCmdProv->Open(NULL);

  return retval;
}


int GenericWnd::onPaint(Canvas *canvas) {
  PaintBltCanvas pbc;
  if (canvas == NULL) {
    pbc.beginPaint(this);
    canvas = &pbc;
  }
  GENERICWND_PARENT::onPaint(canvas);

  canvas->setTextFont("Tahoma");
  canvas->setTextBold(400);
  canvas->setTextColor(RGB(255, 255, 255));
  canvas->setTextSize(14);
  canvas->textOut(10, 20, _("ABOUT:"));
  canvas->textOut(20, 34, _("Gandharva Command Client For Winamp3"));
  canvas->textOut(30, 48, _("(C)Yoshi"));

  return 1;
}


/***********************************************************
***********************************************************/
void GenericWnd::timerCallback(int id)
{
  int lng=100,pos=100,playstatus;
  long result=0;
  char title[2048];

  switch(id){
  case TIMER_ID:
    lng = api->core_getLength(0);
    pos = api->core_getPosition(0);
    playstatus = api->core_getStatus(0);

    if(m_szArtist[0])
      sprintf(title, "%s - %s", m_szArtist, m_szTitle);
    else
      strcpy(title, m_szTitle);

    result = pCmdProv->SendData(playstatus, lng, pos, title);

    if(result > 40000) {
      CMyCoreHandle myCore;
      myCore.ParseLegacyCommand((DWORD)result);
    }
/*
  CMDPROV_STATUS_NOERROR=0,
  CMDPROV_STATUS_CONNECTION_REFUSED,
  CMDPROV_STATUS_BAD_TOKEN,
  CMDPROV_STATUS_BAD_VERSION
*/
    break;
  default:
    GENERICWND_PARENT::timerCallback(id);
  }
}



/***********************************************************
***********************************************************/
int GenericWnd::corecb_onTitleChange(const char *title)
{
  char artist[1024],playstring[1024];
  int datatype = api->metadb_getMetaDataType(MT_ARTIST);

  strcpy(playstring, api->core_getCurrent(0));
  api->metadb_getMetaData(playstring, MT_ARTIST, artist, 1024, datatype);

  if(title)  strcpy(m_szTitle, title);
  if(artist) strcpy(m_szArtist, artist);

  return 0;
}
